@@ -14,7 +14,7 @@ exception.
 use warnings;
 use strict;
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 use Moose::Role;
 use Fcntl qw(:DEFAULT);
@@ -29,6 +29,10 @@ around 'set' => sub {
 	
 	$self->lock_ex($key);
 
+	# pass through in case of delete
+	$self->$set($key, undef)
+		if not defined $value;
+	
 	die '"'.$key.'" already exists'
 		if $self->get($key);
 	
